@@ -21,6 +21,7 @@
 #include "aqhbci/admjobs/jobtan_l.h"
 #include "aqhbci/admjobs/jobvpp.h"
 #include "aqhbci/admjobs/jobvpa.h"
+#include "aqhbci/ajobs/accountjob_l.h"
 
 #include "aqbanking/i18n_l.h"
 
@@ -134,6 +135,11 @@ int AH_OutboxCBox_SendAndReceiveJobWithTanAndVpp(AH_OUTBOX_CBOX *cbox, AH_DIALOG
     return GWEN_ERROR_GENERIC;
   }
 
+  if (vppJob) {
+    DBG_ERROR(AQHBCI_LOGDOMAIN, "Applying VOP results to transfers");
+    AH_OutboxCBox_ApplyVopResultsToTransfers(workJob, AH_Job_VPP_GetResultList(vppJob));
+  }
+
   AH_Job_free(tanJob1);
   AH_Job_free(vppJob);
   return 0;
@@ -184,7 +190,7 @@ int _handleStage1(AH_OUTBOX_CBOX *cbox, AH_DIALOG *dlg, AH_JOB *tanJob1, AH_JOB
     const char *s;
 
     s=AH_Job_VPP_GetVopMsg(vppJob);
-    DBG_ERROR(AQHBCI_LOGDOMAIN, "VPP message: %s", s);
+    DBG_ERROR(AQHBCI_LOGDOMAIN, "VPP message: %s", s?s:"<no msg>");
 
     if (AH_Job_HasResultWithCode(vppJob, 25)) {
       DBG_ERROR(AQHBCI_LOGDOMAIN, "Result of VOP: Names match.");
@@ -195,13 +201,15 @@ int _handleStage1(AH_OUTBOX_CBOX *cbox, AH_DIALOG *dlg, AH_JOB *tanJob1, AH_JOB
       GWEN_Gui_ProgressLog(0, GWEN_LoggerLevel_Notice, I18N("Result of VOP: Transaction rejected (e.g. non-existent IBAN)."));
     }
     else if (AH_Job_HasResultWithCode(vppJob, 3090)) {
-      DBG_ERROR(AQHBCI_LOGDOMAIN, "Let user accept or reject VOP result");
-      rv=AH_OutboxCBox_LetUserConfirmVopResult(cbox, workJob, s);
-      if (rv<0) {
-        DBG_ERROR(AQHBCI_LOGDOMAIN, "Aborted by user (%d)", rv);
-        GWEN_Gui_ProgressLog(0, GWEN_LoggerLevel_Error, I18N("Aborted by user."));
-        return rv;
-      }
+      /* if (s && *s) { */
+        DBG_ERROR(AQHBCI_LOGDOMAIN, "Let user accept or reject VOP result");
+        rv=AH_OutboxCBox_LetUserConfirmVopResult(cbox, workJob, vppJob, s);
+        if (rv<0) {
+          DBG_ERROR(AQHBCI_LOGDOMAIN, "Aborted by user (%d)", rv);
+          GWEN_Gui_ProgressLog(0, GWEN_LoggerLevel_Error, I18N("Aborted by user."));
+          return rv;
+        }
+     /* } */
     }
   }
 
@@ -925,8 +933,10 @@ AH_JOB *_createTanJobDecoupledStageS(AB_PROVIDER *provider, AH_DIALOG *dlg, cons
 AH_JOB *_createVppJob(AB_PROVIDER *provider, AB_USER *user, const AH_JOB *workJob)
 {
   AH_JOB *vppJob;
+  AB_ACCOUNT *account;
 
-  vppJob=AH_Job_VPP_new(provider, user, 0);
+  account=AH_AccountJob_IsAccountJob(workJob)?AH_AccountJob_GetAccount(workJob):NULL;
+  vppJob=AH_Job_VPP_new(provider, user, account, 0);
   if (vppJob) {
     const char *jobCode;
 
